@@ -1,8 +1,7 @@
 from datetime import datetime, date
 from mock import patch, Mock
 from unittest import TestCase
-from swift.common.swob import Request
-from google.cloud.exceptions import NotFound
+from swift.common.swob import Response, Request
 from swift_cloud.drivers.gcp import SwiftGCPDriver
 
 
@@ -63,10 +62,11 @@ class FakeBlob:
 
 
 class FakeBucket:
-    def __init__(self, blob=FakeBlob(), blobs=[], exists=True):
+    def __init__(self, blob=FakeBlob(), blobs=[], labels={}, exists=True):
         self._exists = exists
         self.blob = blob
         self.blobs = blobs
+        self.labels = labels
 
     def exists(self):
         return self._exists
@@ -238,7 +238,7 @@ class SwiftGCPDriverTestCase(TestCase):
 
     def test_call_get_container(self):
         res = self._driver('/v1/account/container', 'GET').response()
-        self.assertEquals(res.status_int, 200)
+        self.assertEquals(res.status_int, 204)
 
     def test_get_container_with_marker_param(self):
         params = {"marker": "test"}
